@@ -27,7 +27,7 @@ our @EXPORT = qw(
 	
 );
 
-our $VERSION = '0.55';
+our $VERSION = '0.56';
 
 
 # Preloaded methods go here.
@@ -106,7 +106,7 @@ Script::Toolbox - Framework for the daily business scripts
   #--------------------------
   # Automatic usage messages
   #--------------------------
-  Usage(); # print a usage message for all options
+  Usage(); # print an usage message for all options
            # if available print also the POD
 
   Usage('This is additional text for the usage');
@@ -161,6 +161,11 @@ Script::Toolbox - Framework for the daily business scripts
   Exit( 1, 'Exit message' ); # exit with returncode 1, 
                              # write exit message via Log()
 
+  Exit( 1, 'Exit message', __FILE__, __LINE__ );
+                             # exit with returncode 1, 
+                             # with code line reference,
+                             # write exit message via Log()
+
   $fh = Open( '> /tmp/xx' ); # return an IO::File object with
                              # /tmp/xx opened for write 
                              # die with logfile entry if failed
@@ -300,10 +305,10 @@ Return a reference to this array or undef if the directory is not readable.
 
 
 
-=item Exit(1,'The reason for the exit.')
+=item Exit(1,'The reason for the exit.', __FILE__, __LINE__)
 
 Exit the script with return value 1. Write the message to the log-channel
-via Log().
+via Log().  __FILE__ and __LINE__ are optional.
 
 
 
@@ -499,7 +504,7 @@ Otherwise default title and headers will be generated.
 =item *
 
 A hash with the keys 'title', 'head' and 'data'. 'title' points to a
-SCALAR value, 'head' points to a array of scalars. 'data' points to
+SCALAR value, 'head' points to an array of scalars. 'data' points to
 an array of arrays or an array of hashes. 
 
 In case of array of hashes, the column heads will be initialized from
@@ -531,7 +536,9 @@ by "\n" as default if <sep> is missing.
 
 There are two types of menues. Regular menues and data menues.
 All menues use the madatory key 'label'. 
-A data menue has the mandatory key 'value'.
+A data menue has the mandatory key 'value' and optional keys 'default' and
+'readOnly'. The latter has some special effects within Menus containers.
+See also addOption() and run().
 
 Optional keys for both types are 'header' and 'footer'. All Entries with
 these keys will be printed on top resp. below the option lines.
@@ -543,8 +550,8 @@ subroutine.
 =item Menus
 
 This is an object oriented container for regular menues. Each menue generated
-by Menus->new() gets a automatic RETURN option with option number zero and 
-must have a unique menue-name.
+by Menus->new() gets an automatic RETURN option with option number zero and 
+must have an unique menue-name.
 
 Menus-Methods:
 
@@ -552,11 +559,13 @@ Menus-Methods:
 
 =item addMenu(<menueDefs>)
 
-Add one or more complete menue definitions to the menues object. A <menueDefs> has this layout:
+Add one or more complete menue definitions to the menues object.
+A <menueDefs> has this layout:
 {<menueName> => [<menueDef>], ...}
 
-<menueDef> is the structure of a simple menue as decribed in item Menu. In the context of
-Menus, a jump target may be also the name of a menue in the same Menus container.
+<menueDef> is the structure of a simple menue as decribed in item Menu.
+In the context of Menus, a jump target may be also the name of a menue
+in the same Menus container.
 
      $m->addMenu({
          'SubMenu' =>[{'label'=>'Opt2'}, {'label'=>'Opt3'}],
@@ -567,9 +576,47 @@ Menus, a jump target may be also the name of a menue in the same Menus container
 
 Add a new option line to the menue <menueName>.
 
-     $m->addOption('MainMenu',  {'label'=>'Opt3',     'jump'=>\&callBack });
-     $m->addOption('MainMenu',  {'label'=>'Sub Menu','jump'=>'SubMenu1'}); 
-     $m->addOption('MainMenu',  {'label'=>'Edit Value','value'=>10});
+     $m->addOption('MainMenu',  {'label'=>'Opt3',      'jump'=>\&callBack });
+     $m->addOption('MainMenu',  {'label'=>'Sub Menu',  'jump'=>'SubMenu1'}); 
+     $m->addOption('MainMenu',  {'label'=>'Edit 1','value'=>10});
+     $m->addOption('MainMenu',  {'label'=>'Edit 2','value'=>10, 'default'=>20});
+     $m->addOption('MainMenu',  {'label'=>'Toggle1', 'readOnly'=>1,
+                                 'value'=>10, 'default'=>20});
+     $m->addOption('MainMenu',  {'label'=>'Toggle2', 'readOnly'=>1, 'value'=>10});
+     $m->addOption('MainMenu',  {'label'=>'Toggle3', 'readOnly'=>1, 'default'=>10});
+     $m->addOption('MainMenu',  {'label'=>'Toggle4', 'readOnly'=>1, });
+
+=over 4
+
+=item Edit 1
+
+Normal edit mode. If you enter <SPACE> the content of value is a space character.
+
+=item Edit 2
+
+Reset to default mode. If you enter <SPACE> the content of value is the
+content of default.
+
+=item Toggle 1
+
+The content of value toggles between 10 and 20 (value and default content).
+
+=item Toggle 2
+
+The content of value toggles between 10 and '' (value and default content).
+
+=item Toggle 3
+
+The content of value toggles between '' and 10 (value and default content).
+
+=item Toggle 4
+
+The content of value toggles between 'x' and '' (value and default content).
+
+
+=back
+
+
 
 =item setHeader(<menueName>,<newHeaderStr>)
 
@@ -584,9 +631,12 @@ Replace the footer of the menue <menueName>.
 Start the menue <menueName>. The run() method returns after 
 the the user has <maxRunCnt> options selected. Default value for <maxRunCnt> is one.
 If <maxRunCnt> is lower than or equal zero, the run() method will never return unless the
-user selects the RETURN option (num=0). The run() method give back the number of the
+user selects the RETURN option (num=0). The run() method returns the number of the
 last selected option.
 
+If the menu runs in endless mode (maxRunCnt < 0), then all <readOnly> options
+will take a special behavior. They are in toggle-mode. See also example at
+addOption().
 
     while( $m->run('MainMenu') ) { ... }
     $num = $m->run('MainMenu', 3);
@@ -634,6 +684,19 @@ Change the data field value of the last selected option. Return the old value.
 
   my $old = $m->currValue ('MainMenu','newValue');
 
+=item setCurrDefault(<menuName>,<newDefault>)
+
+Set a new default for the current selected option of menue <nemuName>.
+Return the old default.
+
+
+=item setCurrReadOnly(<menuName>,<newReadOnly>)
+
+Set the readOnly flag for the current selected option of menue <nemuName>.
+Return the old readOnly state. <newReadOnly> may be 0, 'false' or undef
+for logical false. Any other values means locical true.
+
+
 =item getMatching(<menueName>,<pattern>,<searchIn>,<return>)
 
 Search in the options array of menue named <menueName>. Return the reference
@@ -671,8 +734,12 @@ Disable AutoHeader for all menues or only the one selected by <menueName>.
 
 Return a hash with all label-value pairs of the menu.
 
-=back
+=item getRunCnt(<menuName>)
 
+Return the current value of the running counter of the menu.
+
+
+=back
 
 
 =item DataMenu
@@ -711,6 +778,10 @@ None by default. Can export Dir, Exit, File, KeyMap, Log,
 Now, Open, Table, Usage, System, Stat or :all.
 
 
+=head1 DEPRECATED
+
+Menues, Menue, DataMenue will be removed in version 1.0 ;-)
+
 =head1 SEE ALSO
 
 L<IO::File>, L<Fatal>, L<Script::Toolbox::Util>,
