@@ -4,6 +4,7 @@ use 5.006;
 use strict;
 use Script::Toolbox::Util::Opt;
 use Script::Toolbox::Util::Formatter;
+use Script::Toolbox::Util::Menues;
 use Script::Toolbox::Util::Menus;
 use Script::Toolbox::TableO;
 use IO::File;
@@ -130,10 +131,12 @@ sub _installSigHandlers()
 #------------------------------------------------------------------------------
 # Log a message and exit the programm with the given error code.
 #------------------------------------------------------------------------------
-sub Exit($$)
+sub Exit(@)
 {
-    my ($exitCode, $message) = _getParam(@_);
+    my ($exitCode, $message, $file, $line) = _getParam(@_);
 
+    $message .= sprintf "\n\tSource:%s:%s", $file, $line if( defined $line &&
+                                                         defined $file );
     Log( $message );
     exit $exitCode;
 }
@@ -887,6 +890,18 @@ sub _normMenuOpts($){
     return \@OPTS, $head, $foot;
 }
 
+#------------------------------------------------------------------------------
+#------------------------------------------------------------------------------
+sub _printOption($$$) {
+    my ($op,$form1,$i) = @_;
+
+    my ($def,$form)=_getDefForm($form1,$op);
+    if( defined $def ) {
+        printf $form, $i,$op->{'label'},$def;
+        return;
+    }
+    printf $form, $i,$op->{'label'};
+}
 #------------------------------------------------------------------------------
 # Display a menue, return the selected index number and the menue data structure.
 # If a VALUE or DEFAULT key of a menue option points to a value this value can
@@ -900,8 +915,7 @@ sub _normMenuOpts($){
 # - header=> an optional head line
 # - footer=> an optional footer line
 #------------------------------------------------------------------------------
-sub Menu($)
-{
+sub Menu($) {
     my ($OPTS) = @_;
 
     my ($opts,$head,$foot) = _normMenuOpts($OPTS);
@@ -914,12 +928,7 @@ sub Menu($)
     foreach my $op ( @{$opts} )
     {
         next if( ! $op->{'label'} );
-        my ($def,$form)=_getDefForm($form1,$op);
-        if( defined $def ) {
-            printf $form, $i++,$op->{'label'},$def;
-        }else{
-            printf $form, $i++,$op->{'label'};
-        }
+        _printOption($op,$form1,$i++);
     }
     _printMenuFooter($foot);
     printf "\nSelect: ";
@@ -932,7 +941,7 @@ sub Menu($)
 # Deprecated Menu function. Only for compatibility with legacy software.
 #------------------------------------------------------------------------------
 sub Menue($){
-    return Menu(@_);
+    return Menu($_[0]);
 }
 
 #------------------------------------------------------------------------------
@@ -1066,7 +1075,7 @@ sub DataMenu(@) {
 #------------------------------------------------------------------------------
 # Deprecated Menu function. Only for compatibility with legacy software.
 #------------------------------------------------------------------------------
-sub DataMenue($){
+sub DataMenue(@){
     return DataMenu(@_);
 }
 
@@ -1146,7 +1155,7 @@ sub _getDefForm($$)
     my $def;
     $def = $op->{'value'}   if( defined $op->{'value'} );
     my $form;
-    if( $op->{'readOnly'} ) { $form = defined $def ? "$form1 >%s<" : $form1 }
+    if( $op->{'readOnly'} ) { $form = defined $def ? "$form1 <%s>" : $form1 }
     else                    { $form = defined $def ? "$form1 [%s]" : $form1 }
 
     return $def,"$form\n";
